#
# spec file for package python-pydantic-core
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-pydantic-core%{psuffix}
Version:        2.23.4
Release:        1.1
Summary:        Core functionality for pydantic validation and serialization
License:        MIT
URL:            https://github.com/pydantic/pydantic-core
Source0:        https://files.pythonhosted.org/packages/source/p/pydantic-core/pydantic_core-%{version}.tar.gz
Source1:        vendor.tar.xz
BuildRequires:  %{python_module maturin >= 1}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module typing-extensions >= 4.6.0}
BuildRequires:  cargo-packaging
BuildRequires:  python-rpm-macros
# SECTION test requirements
%if %{with test}
BuildRequires:  %{python_module dirty-equals}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module pydantic-core == %{version}}
BuildRequires:  %{python_module pytest-benchmark}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest-timeout}
BuildRequires:  %{python_module pytest}
%endif
# /SECTION
BuildRequires:  fdupes
Requires:       python-typing-extensions >= 4.6.0
%python_subpackages

%description
This package provides the core functionality for
[pydantic](https://docs.pydantic.dev) validation and serialization.

Pydantic-core is currently around 17x faster than pydantic V1.

%prep
%autosetup -p1 -n pydantic_core-%{version} -a1

%build
# The build takes quite a long time, so we don't want to build this while under test.
%if %{without test}
%pyproject_wheel
%endif

%install
%if %{without test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%endif

%check
%if %{with test}
%pytest_arch
%endif

%if %{without test}
%files %{python_files}
%{python_sitearch}/pydantic_core
%{python_sitearch}/pydantic_core-%{version}.dist-info
%endif

%changelog
* Wed Oct  2 2024 Meera Belur <mbelur@suse.com>
- update 2.23.4
  Clean up serialization warnings for invalid data in unions
  Fix variance issue in `_IncEx` type alias, only allow `True`
  Bump version to v2.23.3
  Fix `_IncEx` type annotation
  Fix tagged union serialization warning when using aliases
  Bump serde_json from 1.0.127 to 1.0.128
  Improve test_valid_complex_string_with_space
  Negative integers with leading zeros raise ValueError
  Bump serde_json from 1.0.121 to 1.0.127
  Bump regex from 1.10.5 to 1.10.6
  Bump uuid from 1.9.1 to 1.10.0
  Bump idna from 1.0.1 to 1.0.2
  Bump serde from 1.0.204 to 1.0.209
  Bump the python-packages group with 8 updates
  Try removing flaky xfail test
  Version bump for docs update
  Adding missing API docs to `pydantic_core`
  Prep for `v2.23.1` patch release
  Refactor `BigInt` boilerplate
  Support `BigInt` serialization for `int` subclasses
  Use more explicit warning regarding serialization warning for missing fields
  Prep for v2.23.0
  Breaking change: Change `metadata` type hint from `Any` -> `Dict[str, Any] | None`
  Adding `cls` reference to `TypedDictSchema`
  Disable automatic assignees with `hooky`
  Version bump to prep for new release
  Introduce `exactness` into `Decimal` validation logic
  Adding tagged union serializer 🚀
  Support complex numbers
  Use `typing_extensions.TypedDict` on Python < 3.12
  For missing fields, we don't warn on `exclude_`, so don't warn on `exclude`
  Fix float serialization behavior in strict mode
  stop clone-ing serializers
  Try each option in union serializer before inference
  Show value of wrongly typed in serialization warning
  Validate base64 standard encoding
  dont embed `RUSTFLAGS` in final binary
  Expose AnySerializer via core schema
  Revert "use little endian int
  Uprev to v2.21.0
  Support `allow_partial='trailing-strings'`
  Bump base64 from 0.21.7 to 0.22.1
  clean up some string handling cases
  Bump serde from 1.0.203 to 1.0.204
  Bump serde_json from 1.0.118 to 1.0.121
  Bump pyo3 from 0.22.0 to 0.22.2
  Bump version_check from 0.9.4 to 0.9.5
  Bump the python-packages group with 7 updates
  Bump CodSpeedHQ/action from 2 to 3
  Validate bytes based on ser_json_bytes
  Fix lints firing since rust 1.80
  Bump idna from 0.5.0 to 1.0.1
  use little endian int
  Fix model field serializer with computed field
  use Uuid:::from_u128 for uuid_to_string
  string: Use 're.Pattern.search' instead of 're.Pattern.match'
  Fixes discriminated union bug regression when using enums
  Bump `speedate` to v0.14.1 and prep for v0.20.1
  Bump the python-packages group across 1 directory with 7 updates
  Bump num-bigint from 0.4.5 to 0.4.6
  Bump uuid from 1.9.0 to 1.9.1
  Bump `pytest-examples` to get tests passing with ruff `v0.5.0`
  try restore 3.13 PGO builds
* Mon Jul  1 2024 Dirk Müller <dmueller@suse.com>
- update to 2.20.0:
  * Tidy up `tagged_union_schema`
  * Improvements in `Union` matching logic during validation
  * Fix `Union` validation logic when `extra='allow'`
  * Add list `fail_fast` config option
  * Update to PyO3 0.22, add Python 3.13 support
- update to 2.19.0:
  * Lower MSRV to 1.75
  * Bump `libc` from 0.2.147 to 0.2.155
  * Make `ValidatorFunctionWrapHandler` positional only
  * Reuse `re.Pattern` object in regex patterns
  * Add ser_json_inf_nan='strings' mode to produce valid JSON
* Thu Jun  6 2024 Dirk Müller <dmueller@suse.com>
- update to 2.18.4:
  * Bump uuid from 1.7.0 to 1.8.0
  * Bump serde from 1.0.197 to 1.0.203
  * Bump the python-packages group with 6 updates
  * Uprev `jiter` to v0.4.1
- update to 2.18.3:
  * Bump `serde_json` from 1.0.114 to 1.0.116
  * Bump the python-packages group with 7 updates
  * Bump `regex` from 1.10.3 to 1.10.4
  * Bump `pyo3` from 0.21.1 to 0.21.2
  * Bump `uraimo/run-on-arch-action` from 2.7.1 to 2.7.2
* Sat Apr 27 2024 Dirk Müller <dmueller@suse.com>
- update to 2.18.2:
  * Support multiple zeros as an `int`
  * Fix validation of `int`s with leading unary plus
  * Fix interaction between `extra != 'ignore'` and
    `from_attributes=True`
  * Handle error from `Enum`'s `missing` function as
    `ValidationError`
  * Fix memory leak with `Iterable` validation
- update to 2.18.1:
  * allow serialization functions to upgrade warnings to
    exceptions
  * Fix: add `coerce_numbers_to_str option` in `StringSchema`
  * Trim leading zeros before parsing `str` -> `int`
  * Prevent trailing dots in integers
- update to 2.18.0:
  * update to PyO3 0.21 final
  * Add coerce_numbers_to_str option in str_schema
  * caching strings from JSON
  * fix build warnings on python <3.11
  * Fixes for `ser_json_inf_nan` inference
  * Adopt jiter `0.2.0`
- update to 2.17.0:
  * Add benchmarks for serializing model with complete schema
  * Prevent panicking when `__dict__` changes during iteration
  * Fix `TzInfo` equality check based on offset
  * Fix stack overflow due to recursion in some recursive
    serializer schemas.
  * Use PEP570 syntax
  * Fix parsing `BigInt` from `str`
  * Use new typing syntax for `_pydantic_core.pyi`
  * separate `Input` trait `'a` and `'py` lifetimes
  * Fix json serialization when `computed_field` is excluded
  * Implement `Input` for `str`
  * Move list validation to produce an associated type
  * Remove `with_new_extra`
  * Associated types for arguments in Input
  * Associated types for dict in input
  * Remaining associated types
  * Refactor `Input` trait to have single `as_python` cast for
    python inputs
  * Allow case where `__pydantic_extra__` is `None`, even if
    `extra='allow'`
  * Add ability to pass `context` to serialization
  * Add `serialize_as_any` runtime flag support
* Tue Mar 12 2024 Steve Kowalik <steven.kowalik@suse.com>
- Sprinkle in multibuild to avoid build cycles.
* Sat Mar  9 2024 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed Mar  6 2024 Steve Kowalik <steven.kowalik@suse.com>
- Initial release of 2.16.3
